==> gcc-3.0.1.tar.gz: gcc-3.0.1/libstdc++-v3/testsuite/27_io/ostream.cc <==
// 1999-09-20 bkoz

// Copyright (C) 1999, 2000 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING.  If not, write to the Free
// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.

// As a special exception, you may use this file as part of a free software
// library without restriction.  Specifically, if other files instantiate
// templates or use macros or inline functions from this file, or you compile
// this file and link it with other files to produce an executable, this
// file does not by itself cause the resulting executable to be covered by
// the GNU General Public License.  This exception does not however
// invalidate any other reasons why the executable file might be covered by
// the GNU General Public License.

// 27.6.2.1 basic_ostream
// NB: This file is for testing ostream with NO OTHER INCLUDES.

#include <ostream>

namespace test {
 
#if 0
  // XXX Should work, but doesn't.
  using namespace std;
  typedef short type_t;
  template class basic_ostream<type_t, char_traits<type_t> >;
#endif

} // test

int main() {
  return 0;
}

==> gcc-3.3.6.tar.gz: gcc-3.3.6/libstdc++-v3/testsuite/27_io/ostream.cc <==
// 1999-09-20 bkoz

// Copyright (C) 1999, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING.  If not, write to the Free
// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.

// As a special exception, you may use this file as part of a free software
// library without restriction.  Specifically, if other files instantiate
// templates or use macros or inline functions from this file, or you compile
// this file and link it with other files to produce an executable, this
// file does not by itself cause the resulting executable to be covered by
// the GNU General Public License.  This exception does not however
// invalidate any other reasons why the executable file might be covered by
// the GNU General Public License.

// 27.6.2.1 basic_ostream
// NB: This file is for testing ostream with NO OTHER INCLUDES.

#include <ostream>
#include <testsuite_hooks.h>

// { dg-do compile }

// libstdc++/7216
void test01()
{
  // Check for required typedefs
  typedef std::ostream test_type;
  typedef test_type::char_type char_type;
  typedef test_type::traits_type traits_type;
  typedef test_type::int_type int_type;
  typedef test_type::pos_type pos_type;
  typedef test_type::off_type off_type;
}

namespace test 
{
  using namespace std;
  using __gnu_cxx_test::pod_char;
  typedef short type_t;
  template class basic_ostream<type_t, char_traits<type_t> >;
  template class basic_ostream<pod_char, char_traits<pod_char> >;
} // test

int main() 
{
  test01();
  return 0;
}
